@@ -4,8 +4,6 @@ use strict;
 use warnings;
 no  warnings 'redefine';
 
-use Squatting ':views';
-
 our $AUTOLOAD;
 
 # constructor
@@ -20,8 +18,13 @@ sub name : lvalue {
   $_[0]->{name};
 }
 
-# $content = $view->render($template)       # render $template
-# $content = $view->render($template, '_')  # render the generic template
+# name of view
+sub headers : lvalue {
+  $_[0]->{headers};
+}
+
+# $content = $view->_render($template)       # render $template
+# $content = $view->_render($template, '_')  # render the generic template
 sub _render {
   my ($self, $template, $vars, $alt) = @_;
   $self->{template} = $template;
@@ -75,7 +78,7 @@ Squatting::View - default view class for Squatting
         my ($self, $v) = @_;
         "You tried to render $self->{template} which was not defined.";
       },
-      arbitrary_data => [ 'is', 'ok', 2 ],
+      arbitrary_data => [ { is => 'ok' }, 2 ],
     )
   );
 
@@ -86,37 +89,39 @@ are represented by subroutine references that will be installed as methods
 of a view object.  The job of a template is to take a hashref of variables
 and return a string.
 
-You may also define a special template named "layout" that's expected to
-also take the output of another template and wrap it.
-
 =head1 API
 
 =head2 General Methods
 
-=head3 Squatting::View->new($name, %methods)
+=head3 $view = Squatting::View->new($name, %methods)
 
 The constructor takes a name and a hash of attributes and coderefs.
+Note that the name must be unique within the package the view is defined.
 
-=head3 $v->name
+=head3 $view->name
 
 This returns the name of the view.
 
+=head3 $view->headers
+
+This returns a hashref of the outgoing HTTP headers.
+
 =head2 Template Methods
 
-=head3 $v->$template($v)
+=head3 $view->$template($v)
 
 Any coderef that was given to the constructor may be called by name.
 Templates should be passed in a hashref ($v) with variables for it
 to use to generate the final output.
 
-=head3 $v->layout($v, @content)
+=head3 $view->layout($v, @content)
 
 If you define a template named "layout", it'll be used to wrap the
 content of all templates whose name do not begin with "_".  You can
 use this feature to provide standard headers and footers for your
 pages.
 
-=head3 $v->_($v)
+=head3 $view->_($v)
 
 If you define a template named "_", this will act as a catch-all
 that can be asked to render anything that wasn't explicitly defined.
